This data set gives the number of days absent from high school and the gender, maths score (standardized score out of 100) and academic programme ('General', 'Academic' and 'Vocational') of 314 students sampled from two urban high schools. The attendance data frame has 314 observations on 5 variables.
Usage
data(attendance)