An function used to extract model coefficients from a 'cmp' object.
coefficients is an alias for coef.
Usage
# S3 method for class 'cmp'
coef(object, ...)An function used to extract model coefficients from a 'cmp' object.
coefficients is an alias for coef.
# S3 method for class 'cmp'
coef(object, ...)