An accessor function used to extract the fitted values from a 'cmp' object.
fitted.values is an alias for fitted.
Usage
# S3 method for class 'cmp'
fitted(object, ...)An accessor function used to extract the fitted values from a 'cmp' object.
fitted.values is an alias for fitted.
# S3 method for class 'cmp'
fitted(object, ...)