Extract the Number of Observation from a COM-Poisson Model Fit
Source:R/summarize_extract.R
nobs.cmp.RdAn accessor function used to extract the number of observation from a 'cmp' object.
Usage
# S3 method for class 'cmp'
nobs(object, ...)R/summarize_extract.R
nobs.cmp.RdAn accessor function used to extract the number of observation from a 'cmp' object.
# S3 method for class 'cmp'
nobs(object, ...)