Skip to contents

print method for class cmp.

Usage

# S3 method for class 'cmp'
print(x, ...)

Arguments

x

an object class 'cmp', obtained from a call to glm.cmp.

...

other arguments passed to or from other methods (currently unused).

Value

x is returned invisibly; print.cmp is called for its side effect of printing the model summary to the console.

Details

print.cmp can be used to print a short summary of object class 'cmp'.

Examples

## For examples see example(glm.cmp)