residuals is a generic function which extracts model residuals from objects
returned by the modelling function glm.comp. resid is an alias for
residuals .
Usage
# S3 method for class 'cmp'
residuals(object, type = c("deviance", "pearson", "response"), ...)
Arguments
- object
an object class 'cmp', obtained from a call to glm.cmp.
- type
the type of residuals which should be returned. The alternatives are:
'deviance' (default), 'pearson' and 'response'. Can be abbreviated.
- ...
other arguments passed to or from other methods (currently unused).
Value
Residuals extracted from the object object.