Calculate the Normalizing Constant in log scale for COM-Poisson distribution The calculation of the function logZ will be performed here. This function is used to approximate the normalizing constant for COM-Poisson distributions via truncation. The standard COM-Poisson parametrization is being used here.
Source: R/RcppExports.R
logZ_c.RdIt is assumed that vectors log_lambda & nu are of equal length.
Value
A numeric vector giving the (approximate) log of the COM-Poisson
normalizing constant \(\log Z(\lambda, \nu)\) for each element of
log_lambda and nu.