print method for class cmp.
Usage
# S3 method for class 'cmp'
print(x, ...)Value
x is returned invisibly; print.cmp is called for its
side effect of printing the model summary to the console.
print method for class cmp.
# S3 method for class 'cmp'
print(x, ...)x is returned invisibly; print.cmp is called for its
side effect of printing the model summary to the console.